@@ -46,13 +46,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <sys/time.h>
 
 
-
-#if defined(SUN4OS5platform)||defined(SGIplatform)
-/* can't find a prototype anywhere */
-extern int utimes(const char *, const struct timeval [2]);
-#endif
-
-
 #define MaxLineLength 512
 #define MaxFiles      100
 
@@ -252,11 +245,7 @@ void
 closeCoverFile(void)
 {
     fclose(coverFile);
-#ifdef HP9platform
-    times("coverex.ht",latest_date);
-#else
     utimes("coverex.ht",latest_date);
-#endif
 }
 
 void
